@@ -284,7 +284,7 @@ if(plot_type==40):
     freq = np.loadtxt('ZS'+appendix, usecols=0)
     meta = len(freq)
     if(gaussian_smoothing != 0.):
-        sig = gaussian_smoothing
+        sig, mi = gaussian_smoothing, freq[int(len(freq)/2)]
         if(gaussian_smoothing < 0):
             print('automatic sigma not allowed in this mode, sigma set to 0.1')
             sig, mi = 0.1, freq[int(len(freq)/2)]
